@@ -26,19 +26,21 @@ import logging
 from datetime import datetime, timezone
 
 from thetaetl.service.graph_operations import GraphOperations, OutOfBoundsError, Point
-from thetaetl.json_rpc_requests import generate_get_blocks_by_range_json_rpc
+from thetaetl.json_rpc_requests import generate_get_blocks_by_range_json_rpc,generate_get_status_json_rpc
 from thetaetl.utils import rpc_response_to_result
 from thetaetl.mappers.block_mapper import ThetaBlockMapper
+from thetaetl.mappers.status_mapper import ThetaStatusMapper
 
 class ThetaService(object):
     def __init__(self, theta_provider):
         graph = BlockTimestampGraph(theta_provider)
         self._graph_operations = GraphOperations(graph)
+        self.logger = logging.getLogger('ThetaService')
 
     def get_block_range_for_date(self, date):
         start_datetime = datetime.combine(date, datetime.min.time().replace(tzinfo=timezone.utc))
-        end_datetime = datetime.combine(date, datetime.min.time().replace(tzinfo=timezone.utc))
-        # end_datetime = datetime.combine(date, datetime.max.time().replace(tzinfo=timezone.utc))
+        end_datetime = datetime.combine(date, datetime.min.time().replace(tzinfo=timezone.utc) + 1)
+        #end_datetime = datetime.combine(date, datetime.max.time().replace(tzinfo=timezone.utc))
         return self.get_block_range_for_timestamps(start_datetime.timestamp(), end_datetime.timestamp())
 
     def get_block_range_for_timestamps(self, start_timestamp, end_timestamp):
@@ -58,6 +60,8 @@ class ThetaService(object):
             raise OutOfBoundsError('The existing blocks do not completely cover the given time range') from e
 
         if start_block_bounds == end_block_bounds and start_block_bounds[0] != start_block_bounds[1]:
+            self.logger.info("end_block_bounds[0] %d,  end_block_bounds[1] : %d, start_block_bounds[0] %d, start_block_bounds[1] %d \n", 
+                end_block_bounds[0], end_block_bounds[1], start_block_bounds[0], start_block_bounds[0])
             raise ValueError('The given timestamp range does not cover any blocks')
 
         start_block = start_block_bounds[1]
@@ -74,6 +78,7 @@ class BlockTimestampGraph(object):
     def __init__(self, theta_provider):
         self._theta_provider= theta_provider
         self.block_mapper = ThetaBlockMapper()
+        self.status_mapper = ThetaStatusMapper()
         self.logger = logging.getLogger('BlockTimestampGraph')
 
     def get_first_point(self):
@@ -82,8 +87,12 @@ class BlockTimestampGraph(object):
 
     def get_last_point(self):
 #        return block_to_point(self._theta_provider.eth.getBlock('latest'))  
-       return Point(2184972, 1596678993) #TODO: query status to get latest
-        # return Point(2182936, 1596671999) #TODO: query status to get latest
+        #return Point(2184972, 1596678993) #TODO: query status to get latest
+        status_rpc = generate_get_status_json_rpc()
+        response = self._theta_provider.make_request(json.dumps(status_rpc))
+        result = rpc_response_to_result(response)
+        status = self.status_mapper.json_dict_to_status(result)
+        return self.get_point(int(status.latest_finalized_block_height))
 
     def get_point(self, x):
 #        return block_to_point(self._theta_provider.eth.getBlock(x))
